#H#######################################################################
# FILENAME :        __init__.c             
# 
# DESIGN REF: https://python-packaging.readthedocs.io/en/latest/minimal.html
#
# DESCRIPTION :
#       This file is to make Python treat the directories as containing
#       packages; this is done to prevent directories with a common name, 
#       such as string, from unintentionally hiding valid modules that 
#       occur later on the module search path.
#
# PUBLIC FUNCTIONS :
#       joke()
#
# NOTES :
#       This file can be simply empty and the function is just for fun.
#
#       Copyright: .  All rights reserved.
# 
# AUTHOR :          Jinhang <jinhang.d.zhu@gmail.com>
# VERSION :         1.0    
# START DATE :      07 Mar. 2019
#
# CHANGES :
#
# NO    VERSION     DATE        WHO     DETAIL
# 1     1.0         07 Mar. 19  J.Z     Initialization
#
#H#

def greet():
    return ('I AM HERE.')


# Installing Packages Locally from Source
# python setup.py install --user
# For installing using: pip install .
# Go into this directory firstly

from setuptools import setup

setup(name='myimpy',
      version='1.1',
      description='Imaging processing methods',
      url='https://github.com/JinhangZhu/myimpy',
      author='Jinhang Zhu',
      author_email='jinhang.d.zhu@gmail.com',
      license='MIT',
      packages=['myimpy'],
      package_dir={'jinhang': 'myimpy'},
      package_data={'jinhang':['*.*', 'myimpy/*']},
      zip_safe=False)